@@ -5,6 +5,7 @@ verify result with different settings in `cookiecutter.json`.
 """
 import os
 import textwrap
+from pathlib import Path
 
 import pytest
 
@@ -65,9 +66,8 @@ def test_cookiecutter_no_input_return_rendered_file():
     """Verify Jinja2 templating correctly works in `cookiecutter.json` file."""
     project_dir = main.cookiecutter('tests/fake-repo-pre', no_input=True)
     assert project_dir == os.path.abspath('fake-project')
-    with open(os.path.join(project_dir, 'README.rst')) as fh:
-        contents = fh.read()
-    assert "Project name: **Fake Project**" in contents
+    content = Path(project_dir, 'README.rst').read_text()
+    assert "Project name: **Fake Project**" in content
 
 
 @pytest.mark.usefixtures('clean_system', 'remove_additional_dirs')
@@ -76,11 +76,9 @@ def test_cookiecutter_dict_values_in_context():
     project_dir = main.cookiecutter('tests/fake-repo-dict', no_input=True)
     assert project_dir == os.path.abspath('fake-project-dict')
 
-    with open(os.path.join(project_dir, 'README.md')) as fh:
-        contents = fh.read()
-
+    content = Path(project_dir, 'README.md').read_text()
     assert (
-        contents
+        content
         == textwrap.dedent(
             """
         # README
